@@ -123,25 +123,16 @@ meteo_imgw_monthly_bp = function(rank,
     #download.file(address, temp)
     unzip(zipfile = temp, exdir = temp2)
     file1 = paste(temp2, dir(temp2), sep = "/")[1]
-
-    if (translit) {
-      data1 = as.data.frame(data.table::fread(cmd = paste("iconv -f CP1250 -t ASCII//TRANSLIT", file1)))
-    } else {
-      data1 = suppressWarnings(read.csv(file1, header = FALSE, stringsAsFactors = FALSE, fileEncoding = "CP1250"))
-    }
+    data1 = imgw_read(translit, file1)
 
     colnames(data1) = meta[[1]]$parameters
 
     if (rank != "precip") { # w opadowkach jest tylko jeden plik
       file2 = paste(temp2, dir(temp2), sep = "/")[2]
-
-      if (translit) {
-        data2 = as.data.frame(data.table::fread(cmd = paste("iconv -f CP1250 -t ASCII//TRANSLIT", file2)))
-      } else {
-        data2 = read.csv(file2, header = FALSE, stringsAsFactors = FALSE, fileEncoding = "CP1250")
+      if (file.exists(file2)) {
+        data2 = imgw_read(translit, file2)
+        colnames(data2) = meta[[2]]$parameters
       }
-
-      colnames(data2) = meta[[2]]$parameters
     }
 
     # removing status if set
